ChannelException class
A logical channel was closed or referenced after teardown.
- Inheritance
-
- Object
- OmnyShellException
- ChannelException
Constructors
- ChannelException(String message, {String? code})
-
Creates a channel exception.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited