ChannelSignal class final

Deliver a POSIX signal to the session's process.

Inheritance

Constructors

ChannelSignal({required int channel, required String signal})
Creates a signal.
const

Properties

channel int
The channel id.
final
channelId int?
The channel this message pertains to, or null for connection-level messages (the envelope c field).
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signal String
The signal name (e.g. SIGINT).
final
type String
The stable type discriminator (the envelope t field).
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
The message payload (the envelope d field), without the type or channel.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(int? channel, Map<String, dynamic> d) ChannelSignal
Decodes a ChannelSignal.

Constants

typeName → const String
The type discriminator.