currentCwd property
The session's current working directory, or null when it could not be
determined.
Implementation
final String? currentCwd;
The session's current working directory, or null when it could not be
determined.
final String? currentCwd;