protocolError constant
String
const protocolError
A frame could not be decoded or violated the protocol.
Implementation
static const String protocolError = 'protocol_error';
A frame could not be decoded or violated the protocol.
static const String protocolError = 'protocol_error';