unknownNode constant
String
const unknownNode
The requested node is not registered with the Hub.
Implementation
static const String unknownNode = 'unknown_node';
The requested node is not registered with the Hub.
static const String unknownNode = 'unknown_node';