NodeSessionRejected class final

Node → Hub: the node refused the session.

Inheritance

Constructors

NodeSessionRejected({required int channel, required String sessionId, required String reason, required String message})
Creates a node-session-rejected.
const

Properties

channel int
The node-side channel id.
final
channelId int?
The channel this message pertains to, or null for connection-level messages (the envelope c field).
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable message.
final
reason String
A machine reason.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
The session id.
final
type String
The stable type discriminator (the envelope t field).
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
The message payload (the envelope d field), without the type or channel.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(int? channel, Map<String, dynamic> d) NodeSessionRejected
Decodes a NodeSessionRejected.

Constants

typeName → const String
The type discriminator.