PrincipalId class

Identity of an authenticated principal (a user or a node account) as known to the Hub. Equality is by value.

Constructors

PrincipalId(String value)
Creates and validates a principal id.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The raw identifier string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override