ProtocolError class final

A connection- or channel-level error.

Inheritance

Constructors

ProtocolError({required String code, required String message, bool fatal = false, int? channel})
Creates a protocol error.
const

Properties

channel int?
The channel the error pertains to, if any.
final
channelId int?
The channel this message pertains to, or null for connection-level messages (the envelope c field).
no setteroverride
code String
A stable error code (see ErrorCodes).
final
fatal bool
Whether the error is fatal (the sender will close the connection).
final
hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The stable type discriminator (the envelope t field).
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
The message payload (the envelope d field), without the type or channel.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(int? channel, Map<String, dynamic> d) ProtocolError
Decodes a ProtocolError.

Constants

typeName → const String
The type discriminator.