TransportException class

The underlying transport failed or closed unexpectedly.

Inheritance

Constructors

TransportException(String message)
Creates a transport exception.
const

Properties

code String
A stable, machine-readable error code.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable description of the failure.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited