TunnelCloseResponse class final
Hub → Client: the result of a tunnel close. Correlated by requestId.
- Inheritance
-
- Object
- ControlMessage
- TunnelCloseResponse
Constructors
- TunnelCloseResponse({required String requestId, required bool ok, String message = ''})
-
Creates a tunnel-close response.
const
Properties
- channelId → int?
-
The channel this message pertains to, or
nullfor connection-level messages (the envelopecfield).no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A human-readable result/error message.
final
- ok → bool
-
Whether a tunnel was found, owned by the caller, and closed.
final
- requestId → String
-
The correlation id from the request.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The stable type discriminator (the envelope
tfield).no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
The message payload (the envelope
dfield), without the type or channel.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
int? channel, Map< String, dynamic> d) → TunnelCloseResponse - Decodes a TunnelCloseResponse.