newId function
Generates a new globally-unique identifier (UUID v4).
Used for session ids and other entities when the caller does not supply one. The value is a 36-character canonical UUID string.
Implementation
String newId() => _uuid.v4();
Generates a new globally-unique identifier (UUID v4).
Used for session ids and other entities when the caller does not supply one. The value is a 36-character canonical UUID string.
String newId() => _uuid.v4();