DashboardActionResult class

The outcome of a fire-and-forget session action (detach / terminate) that the dashboard shows in its message bar.

Constructors

DashboardActionResult({required bool ok, required String message})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
A short human-readable result to display.
final
ok bool
Whether the action succeeded.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited