aiTest abstract method
Validates the configured key and models with live provider requests.
Implementation
Future<List<AiModelCheck>> aiTest();
Validates the configured key and models with live provider requests.
Future<List<AiModelCheck>> aiTest();