mountConflicts abstract method
Lists the files that differ between local and node for mountId.
Implementation
Future<DriveChanges> mountConflicts(
String mountId, {
bool includeDiffs = false,
});
Lists the files that differ between local and node for mountId.
Future<DriveChanges> mountConflicts(
String mountId, {
bool includeDiffs = false,
});