DetachedSessionKillResult class

Constructors

DetachedSessionKillResult({required bool ok, required String message})
Creates a kill result.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable result/error message.
final
ok bool
Whether the session was found, owned by the caller, and terminated.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited