diffs property
Per-conflict diffs, keyed by path — populated only when the caller asked for them (see DriveManager.conflicts); empty otherwise.
Implementation
final Map<String, FileDiff> diffs;
Per-conflict diffs, keyed by path — populated only when the caller asked for them (see DriveManager.conflicts); empty otherwise.
final Map<String, FileDiff> diffs;