hasConflicts property
bool
get
hasConflicts
True when at least one path was edited on both sides.
Implementation
bool get hasConflicts => conflicts.isNotEmpty;
True when at least one path was edited on both sides.
bool get hasConflicts => conflicts.isNotEmpty;