DriveConflictException class
Raised when an automatic sync cannot proceed because both sides changed.
- Inheritance
-
- Object
- DriveException
- DriveConflictException
Constructors
- DriveConflictException(String message)
- Creates a conflict exception.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited