hasContent property
bool
get
hasContent
True when content bytes are available for a line-level diff.
Implementation
bool get hasContent => localBytes != null || originBytes != null;
True when content bytes are available for a line-level diff.
bool get hasContent => localBytes != null || originBytes != null;