origin property
FileManifestEntry?
origin
final
The origin entry, or null when the file is absent on the node.
Implementation
final FileManifestEntry? origin;
The origin entry, or null when the file is absent on the node.
final FileManifestEntry? origin;