FileResolveOutcome class

The outcome of resolving a single path on a directory mount.

Constructors

FileResolveOutcome({required MountRecord record, required String path, required String strategy, required bool converged})
Creates a per-file resolve outcome.

Properties

converged bool
True when this was the mount's last divergence, so it is now clean.
final
hashCode int
The hash code for this object.
no setterinherited
path String
The path that was resolved.
final
record MountRecord
The (possibly re-anchored) mount record after resolution.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strategy String
The strategy applied: accept-local or accept-origin.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited