setPrompt method
Updates the prompt shown before the input and repaints the current line.
Implementation
void setPrompt(String prompt) {
_prompt = prompt;
if (interactive && !_passthrough) _refresh();
}
Updates the prompt shown before the input and repaints the current line.
void setPrompt(String prompt) {
_prompt = prompt;
if (interactive && !_passthrough) _refresh();
}