currentRemoteCwd property
Returns the current remote working directory, if known, so commands can
resolve relative remote paths. null when unavailable.
Implementation
final String? Function()? currentRemoteCwd;
Returns the current remote working directory, if known, so commands can
resolve relative remote paths. null when unavailable.
final String? Function()? currentRemoteCwd;