requestDetach method

void requestDetach()

Requests that the host leave the interactive session because it was detached: the connection should be dropped but the session left running.

Implementation

void requestDetach() {
  _detachRequested = true;
  _exitRequested = true;
}