ManifestEntry class

One file in a transfer manifest (path is POSIX-relative to the transfer root; size is the uncompressed byte length).

Constructors

ManifestEntry(String path, int size)
Creates a manifest entry.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
path → String
POSIX-relative path including the transferred top-level name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
Uncompressed size in bytes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
JSON form.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> j) → ManifestEntry
Parses a manifest entry.