ephemeral property

bool ephemeral
final

Whether the node path was auto-generated (an ephemeral run/exec --mount mount) rather than supplied via --mount-path. Lets run reuse a previous ephemeral mount for the same local dir without colliding with an explicit fixed-path mount.

Implementation

final bool ephemeral;