grantWindow method
Grants the peer credit more bytes of send window (transfer flow control).
Implementation
void grantWindow(int credit) => _channel.sendControl(
ChannelWindow(channel: _channel.id, stream: 'stdout', credit: credit),
);
Grants the peer credit more bytes of send window (transfer flow control).
void grantWindow(int credit) => _channel.sendControl(
ChannelWindow(channel: _channel.id, stream: 'stdout', credit: credit),
);