writeStdin method

void writeStdin(
  1. List<int> data, {
  2. void onFlushed(
    1. int sentSoFar
    )?,
})

Writes data to the remote standard input.

When onFlushed is supplied it reports the cumulative bytes of data put on the wire as send credit allows — see Channel.sendStdin.

Implementation

void writeStdin(List<int> data, {void Function(int sentSoFar)? onFlushed}) =>
    _channel.sendStdin(data, onFlushed: onFlushed);