transferredPaths property

List<String> transferredPaths
final

Paths whose content was sent over the wire (directory mounts; empty for git, which syncs atomically on the node).

Implementation

final List<String> transferredPaths;