TransferProgress class
Progress notification emitted while a transfer runs.
Constructors
Properties
- bytesDone → int
-
Uncompressed bytes transferred so far across all entries.
final
- bytesTotal → int
-
Total uncompressed bytes to transfer across all entries.
final
- currentPath → String
-
The entry currently transferring.
final
- filesDone → int
-
Files fully transferred so far.
final
- filesTotal → int
-
Total number of files.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited