isConfirmed property
bool
get
isConfirmed
Whether the abort is confirmed and the loop should stop without asking.
Implementation
bool get isConfirmed => _confirmed;
Whether the abort is confirmed and the loop should stop without asking.
bool get isConfirmed => _confirmed;