AgentEnvironment class

Facts about the target node, woven into the system prompt so the model knows what it is operating.

Constructors

AgentEnvironment({required String os, required String arch, required String hostname, String? cwd})
const

Properties

arch String
final
cwd String?
The current remote working directory, if known.
final
hashCode int
The hash code for this object.
no setterinherited
hostname String
final
os String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited