confirmCommand property

Future<CommandConfirm> Function(String prompt)? confirmCommand
final

Asks the user to confirm a command, allowing an "explain" answer. When null, command confirmation falls back to confirm (no explain option).

Implementation

final Future<CommandConfirm> Function(String prompt)? confirmCommand;