AgentPlan class

A plan the model presents (in AgentMode.plan) before executing.

Constructors

AgentPlan({String? summary, required List<AgentPlanStep> steps})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps List<AgentPlanStep>
final
summary String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited