planRule method

String planRule(
  1. String text
)

The separator rule shown just before a plan — a distinct char and color from rule — that sets the plan apart from the preceding investigation.

Implementation

String planRule(String text) => text;