AiModelCheck class

The outcome of validating one model with a live provider request.

Constructors

AiModelCheck({required String model, required bool ok, String? error, int? latencyMs})
const

Properties

error String?
The failure message when ok is false (e.g. 401: invalid x-api-key).
final
hashCode int
The hash code for this object.
no setterinherited
latencyMs int?
Round-trip time of the validation request, in milliseconds.
final
model String
final
ok bool
Whether the request succeeded (the key and model are usable).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited