wantsTools property
bool
get
wantsTools
Whether the model requested at least one tool call.
Implementation
bool get wantsTools => toolCalls.isNotEmpty;
Whether the model requested at least one tool call.
bool get wantsTools => toolCalls.isNotEmpty;