AiToolSpec class

A tool the model is allowed to call. parameters is a JSON-Schema object.

Constructors

AiToolSpec({required String name, required String description, required Map<String, Object?> parameters})
const

Properties

description → String
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
parameters → Map<String, Object?>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited