planRule method

  1. @override
String planRule(
  1. String text
)
override

The separator rule shown just before a plan — a distinct char and color from rule — that sets the plan apart from the preceding investigation.

Implementation

@override
String planRule(String text) => _sgr(35, text);