DriveCredentialResult class

The result of ClientRuntime.peekSession: the current screen snapshot of a session, captured without attaching to it. The result of a drive credential RPC against a node.

Constructors

DriveCredentialResult({required bool ok, required String message, List<DriveCredentialEntry> entries = const []})
Creates a drive-credential result.
const

Properties

entries List<DriveCredentialEntry>
The caller's masked credentials (for list; empty otherwise).
final
hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable result/error message.
final
ok bool
Whether the operation succeeded.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited