reset method
void
reset()
Resets browsing so the next up recomputes the prefix from the current input. Call after any edit to the line and after recording a command.
Implementation
void reset() {
_index = _history.length;
_stash = '';
_searchPrefix = null;
}