provider property
The provider token, used by the Hub to pick the credential scheme when
credentialMode is hubDefault.
Implementation
final String? provider;
The provider token, used by the Hub to pick the credential scheme when
credentialMode is hubDefault.
final String? provider;