send method

  1. @override
Future<StreamedResponse> send(
  1. BaseRequest request
)

Sends an HTTP request and asynchronously returns the response.

Implementers should call BaseRequest.finalize to get the body of the request as a ByteStream. They shouldn't make any assumptions about the state of the stream; it could have data written to it asynchronously at a later point, or it could already be closed when it's returned. Any internal HTTP errors should be wrapped as ClientExceptions.

Implementation

@override
Future<http.StreamedResponse> send(http.BaseRequest request) async {
  final body = await request.finalize().bytesToString();
  final response = await client.proxyHttp(
    method: request.method,
    url: request.url.toString(),
    headers: Map<String, String>.from(request.headers),
    body: body,
    credentialMode: credentialMode,
    provider: provider,
  );
  if (response.error != null) {
    throw http.ClientException(response.error!, request.url);
  }
  final bytes = utf8.encode(response.body);
  return http.StreamedResponse(
    Stream.value(bytes),
    response.statusCode,
    contentLength: bytes.length,
    request: request,
    headers: response.headers,
  );
}