dispose method
Stops driving the session without detaching or closing it (host unmount).
Implementation
Future<void> dispose() => _teardown();
Stops driving the session without detaching or closing it (host unmount).
Future<void> dispose() => _teardown();