onExit property
The session ended with the given exit code (or -1 if it closed uncleanly).
Implementation
final void Function(int code)? onExit;
The session ended with the given exit code (or -1 if it closed uncleanly).
final void Function(int code)? onExit;