KeyEvent class

An immutable decoded key press.

Constructors

KeyEvent(KeyType type, {int? rune, String? ctrl})
const
KeyEvent.char(int rune)
A printable-character event for rune.
factory
KeyEvent.ctrl(String letter)
A Ctrl-letter event for letter (lowercase).
factory

Properties

ctrl String?
The lowercase letter for a KeyType.ctrlChar event (e.g. 's' for Ctrl-S), else null.
final
hashCode int
The hash code for this object.
no setteroverride
rune int?
The Unicode code point for a KeyType.char event, else null.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The character for a KeyType.char event (empty otherwise).
no setter
type KeyType
final

Methods

isCtrl(String letter) bool
Whether this is Ctrl-[letter].
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override