KeyType enum

The kind of a KeyEvent.

Inheritance
Available extensions

Values

char → const KeyType

A printable character; KeyEvent.rune holds the code point.

enter → const KeyType
tab → const KeyType
backTab → const KeyType
backspace → const KeyType
delete → const KeyType
escape → const KeyType
up → const KeyType
down → const KeyType
left → const KeyType
home → const KeyType
end → const KeyType
pageUp → const KeyType
pageDown → const KeyType
ctrlChar → const KeyType

A Ctrl-modified letter; KeyEvent.ctrl holds the lowercase letter.

unknown → const KeyType

An unrecognised sequence (ignored by widgets).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KeyType>
A constant List of the values in this enum, in order of their declaration.