RemoteCommandRunner class
A CommandRunner that runs commands on a remote node via the connected
ClientRuntime (executeStreaming), decoding the byte stream into output
lines. dart:io-free, so it works in the web client too.
- Implemented types
Constructors
- RemoteCommandRunner({required ClientRuntime client, required String nodeId, ShellFamily? shellFamily})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shellFamily → ShellFamily?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
String command, String cwd) → CommandExecution -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited