SessionCommandResult class

The captured result of running a command in the host's interactive session (see LocalCommandContext.runInSession).

Constructors

SessionCommandResult({required int? exitCode, required String output})
const

Properties

exitCode int?
The command's exit code, or null if the shell did not report one.
final
hashCode int
The hash code for this object.
no setterinherited
output String
The command's captured output (stdout + stderr, marker-stripped).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited