ShellPromptState class

The remote shell's prompt context, reported to the host when the shell returns to its (idle) prompt so the host can render a prompt line.

Constructors

ShellPromptState({String? cwd, String? branch, String? gitStatus, String? privilege})
Creates a prompt state.
const

Properties

branch String?
The git branch of cwd, or null outside a repo.
final
cwd String?
The remote working directory, or null if unknown.
final
gitStatus String?
Compact git status (+staged ~modified ?untracked), or null when clean.
final
hashCode int
The hash code for this object.
no setterinherited
isRoot bool
Whether the remote session is the superuser.
no setter
privilege String?
Privilege label (root for the superuser), or null.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited