id property
SessionId?
get
id
The session id, if known (used as the marker nonce so a resumed session derives the same completion token).
Implementation
SessionId? get id;
The session id, if known (used as the marker nonce so a resumed session derives the same completion token).
SessionId? get id;