present abstract method
Renders frame, diffed against the previous one, optionally placing the
hardware cursor.
Implementation
void present(ScreenBuffer frame, {int? cursorX, int? cursorY});
Renders frame, diffed against the previous one, optionally placing the
hardware cursor.
void present(ScreenBuffer frame, {int? cursorX, int? cursorY});