cache property
The cache the Hub granted (sizes after its limits), or null — none was
asked for, the Hub disables tunnel caching, or it predates it.
Implementation
final TunnelCacheOptions? cache;
The cache the Hub granted (sizes after its limits), or null — none was
asked for, the Hub disables tunnel caching, or it predates it.
final TunnelCacheOptions? cache;