AgentPhase enum

Which phase of the agent loop a model request belongs to, used to pick the model via AiConfig.modelFor.

Inheritance
Available extensions

Values

planning → const AgentPhase

Investigation / read-only probing / deciding the next action. Uses the (usually stronger) planner model.

executing → const AgentPhase

Carrying out a mutating command or running an approved plan. Uses the (usually cheaper) executor model.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AgentPhase>
A constant List of the values in this enum, in order of their declaration.