aiConfig property

AiConfig? aiConfig
final

The Hub's default AI configuration (e.g. from AiConfigIo.load()), used to proxy AI requests on behalf of browser clients with the key injected Hub-side, and to advertise a default provider/model. When null the Hub still proxies requests that carry the client's own key, but cannot inject credentials or advertise a default.

Implementation

final AiConfig? aiConfig;