identityCertificate property
The leaf TLS certificate (PEM or DER bytes) used to derive this hub's deterministic UID from its public key (SPKI). When omitted the hub runs without a computed UID.
Implementation
final Uint8List? identityCertificate;
The leaf TLS certificate (PEM or DER bytes) used to derive this hub's deterministic UID from its public key (SPKI). When omitted the hub runs without a computed UID.
final Uint8List? identityCertificate;