tlsReloadInterval property
How often the Hub re-checks tlsDirectory for a renewed certificate. Kept below a day so a renewal is always picked up within 24h.
Implementation
final Duration tlsReloadInterval;
How often the Hub re-checks tlsDirectory for a renewed certificate. Kept below a day so a renewal is always picked up within 24h.
final Duration tlsReloadInterval;