remove method
Removes the node with id from the registry, returning the removed
record if present.
Implementation
RegisteredNode? remove(NodeId id) => _byId.remove(id.value);
Removes the node with id from the registry, returning the removed
record if present.
RegisteredNode? remove(NodeId id) => _byId.remove(id.value);