TokenGrant class

A token and the identity it grants.

Constructors

TokenGrant({required PrincipalId principal, String displayName = '', Set<String> roles = const {}})
Creates a token grant.

Properties

displayName → String
A human-friendly display name.
final
hashCode → int
The hash code for this object.
no setterinherited
principal → PrincipalId
The principal the token authenticates.
final
roles → Set<String>
Roles granted on successful authentication.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited