secure property
Whether the public port terminates TLS (HTTPS). When true, accepted connections are upgraded with the Hub's tunnel TLS context before bridging.
Implementation
final bool secure;
Whether the public port terminates TLS (HTTPS). When true, accepted connections are upgraded with the Hub's tunnel TLS context before bridging.
final bool secure;