tunnelEnabled property
Whether this node accepts tunnel connections (SessionMode.tunnel) — i.e.
dials a local target and bridges bytes when the Hub forwards a public TCP
connection. Default true.
Implementation
final bool tunnelEnabled;
Whether this node accepts tunnel connections (SessionMode.tunnel) — i.e.
dials a local target and bridges bytes when the Hub forwards a public TCP
connection. Default true.
final bool tunnelEnabled;