detachedSessions property
int
get
detachedSessions
The number of detached sessions held in this node's memory.
Implementation
int get detachedSessions => _detached.length;
The number of detached sessions held in this node's memory.
int get detachedSessions => _detached.length;