NodeState enum

The lifecycle state of a NodeRuntime.

Inheritance
Available extensions

Values

disconnected → const NodeState

Not connected.

connecting → const NodeState

Dialing the Hub / completing the WebSocket upgrade.

authenticating → const NodeState

Authenticating with the Hub.

registering → const NodeState

Registering and advertising capabilities.

serving → const NodeState

Connected, registered and serving sessions.

backoff → const NodeState

Backing off before a reconnect attempt.

stopped → const NodeState

Permanently stopped (bad credentials or an explicit shutdown).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NodeState>
A constant List of the values in this enum, in order of their declaration.