allowCommand property
Optional guard; when provided and it returns false, the session is
refused (the runtime reports node.session.rejected).
Implementation
final bool Function(ShellRequest request)? allowCommand;
Optional guard; when provided and it returns false, the session is
refused (the runtime reports node.session.rejected).
final bool Function(ShellRequest request)? allowCommand;