shellFamily property
The command-language family of the launched shell, so the client can speak the matching marker/command dialect over an interactive session.
Implementation
@override
final ShellFamily shellFamily;
The command-language family of the launched shell, so the client can speak the matching marker/command dialect over an interactive session.
@override
final ShellFamily shellFamily;