WindowsTaskException class

Thrown when a schtasks lifecycle operation fails.

Implemented types

Constructors

WindowsTaskException(String message, {bool permissionDenied = false})
Creates a Windows task exception.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable description of the failure.
final
permissionDenied bool
Whether the failure looks like a missing-elevation (access denied) error.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited