AuthRequest class final
A login attempt presenting a credential.
- Inheritance
-
- Object
- ControlMessage
- AuthRequest
Constructors
Properties
- channelId → int?
-
The channel this message pertains to, or
nullfor connection-level messages (the envelopecfield).no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- method → String
-
publicKeyortoken.final - principal → String
-
The claimed principal (login name).
final
- publicKey → String?
-
Base64 Ed25519 public key (publicKey method).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → String?
-
Base64 Ed25519 signature over the connection nonce (publicKey method).
final
- token → String?
-
Bearer token (token method).
final
- type → String
-
The stable type discriminator (the envelope
tfield).no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
The message payload (the envelope
dfield), without the type or channel.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
int? channel, Map< String, dynamic> d) → AuthRequest - Decodes an AuthRequest.