ChannelExit class final
Node → Client: the process exited.
- Inheritance
-
- Object
- ControlMessage
- ChannelExit
Constructors
- ChannelExit({required int channel, required int exitCode, required DateTime ts, String? signal})
-
Creates an exit.
const
Properties
- channel → int
-
The channel id.
final
- channelId → int?
-
The channel this message pertains to, or
nullfor connection-level messages (the envelopecfield).no setteroverride - exitCode → int
-
The process exit code.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signal → String?
-
The terminating signal name, if the process was killed by a signal.
final
- ts → DateTime
-
When the process exited.
final
- type → String
-
The stable type discriminator (the envelope
tfield).no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
The message payload (the envelope
dfield), without the type or channel.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
int? channel, Map< String, dynamic> d) → ChannelExit - Decodes a ChannelExit.