ChannelResize class final
Resize the terminal of an interactive session.
- Inheritance
-
- Object
- ControlMessage
- ChannelResize
Constructors
- ChannelResize({required int channel, required int cols, required int rows})
-
Creates a resize.
const
Properties
- channel → int
-
The channel id.
final
- channelId → int?
-
The channel this message pertains to, or
nullfor connection-level messages (the envelopecfield).no setteroverride - cols → int
-
New width in columns.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rows → int
-
New height in rows.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The stable type discriminator (the envelope
tfield).no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
The message payload (the envelope
dfield), without the type or channel.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
int? channel, Map< String, dynamic> d) → ChannelResize - Decodes a ChannelResize.