ChannelWindow class final
Backpressure credit grant for a stream on a channel.
- Inheritance
-
- Object
- ControlMessage
- ChannelWindow
Constructors
- ChannelWindow({required int channel, required String stream, required int credit})
-
Creates a window update.
const
Properties
- channel → int
-
The channel id.
final
- channelId → int?
-
The channel this message pertains to, or
nullfor connection-level messages (the envelopecfield).no setteroverride - credit → int
-
Additional bytes the receiver is now willing to accept.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stream → String
-
The stream the credit applies to (
stdin,stdout,stderr).final - type → String
-
The stable type discriminator (the envelope
tfield).no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
The message payload (the envelope
dfield), without the type or channel.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
int? channel, Map< String, dynamic> d) → ChannelWindow - Decodes a ChannelWindow.