ControlFrame class final
A control message frame (carried as a WebSocket text frame).
- Inheritance
-
- Object
- OmnyShellFrame
- ControlFrame
- Annotations
-
- @immutable
Constructors
- ControlFrame(ControlMessage message)
-
Wraps
messageas a frame.const
Properties
- channelId → int?
-
The channel this frame belongs to (
null/0for connection control).no setteroverride - hashCode → int
-
The hash code for this object.
no setterinherited
- message → ControlMessage
-
The wrapped control message.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited