DataFrame class final
A binary stream-data frame (carried as a WebSocket binary frame) with a fixed 10-byte header followed by the raw payload bytes.
- Inheritance
-
- Object
- OmnyShellFrame
- DataFrame
- Annotations
-
- @immutable
Constructors
- DataFrame({required DataOpcode opcode, required int channel, required Uint8List payload, int version = kProtocolVersion})
-
Creates a data frame, defaulting
versionto the current protocol.
Properties
- channel → int
-
The channel id (uint32).
final
- channelId → int?
-
The channel this frame belongs to (
null/0for connection control).no setteroverride - hashCode → int
-
The hash code for this object.
no setterinherited
- opcode → DataOpcode
-
Which stream the payload belongs to.
final
- payload → Uint8List
-
The raw stream bytes.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → int
-
The protocol version byte.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited