DriveCredentialEntry class
One masked git-credential entry returned by a list (secrets never leave the
node — description is the credential's masked toString).
Constructors
- DriveCredentialEntry({required String host, required String description})
-
const
Properties
- description → String
-
The masked, human-readable credential description.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String
-
The git host (e.g.
github.com).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> d) → DriveCredentialEntry