NodeDetachedSessionsResponse class final
Node → Hub: the principal's detached sessions. Correlated by requestId.
- Inheritance
-
- Object
- ControlMessage
- NodeDetachedSessionsResponse
Constructors
-
NodeDetachedSessionsResponse({required String requestId, required List<
DetachedSessionInfo> sessions}) -
Creates a node detached-sessions list response.
const
Properties
- channelId → int?
-
The channel this message pertains to, or
nullfor connection-level messages (the envelopecfield).no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- requestId → String
-
The correlation id from the request.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sessions
→ List<
DetachedSessionInfo> -
The matching detached sessions (already filtered by owner).
final
- type → String
-
The stable type discriminator (the envelope
tfield).no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
The message payload (the envelope
dfield), without the type or channel.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
int? channel, Map< String, dynamic> d) → NodeDetachedSessionsResponse - Decodes a NodeDetachedSessionsResponse.