NodeId class
Stable identity of a node, used by clients to address it (instead of a
host:port). Equality is by value.
A node id is a non-empty, trimmed token (letters, digits, _, -, .).
It is supplied by the node operator and registered with the Hub.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override