ActiveSessionDetachResult class
The result of ClientRuntime.detachActiveSession.
Constructors
- ActiveSessionDetachResult({required bool ok, required String shortId, required String message})
-
Creates an active-detach result.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A human-readable result/error message.
final
- ok → bool
-
Whether an owned active session was found and detached.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortId → String
-
The short handle of the detached session (empty on failure), used to
resume it later.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited