ClientTransferLink class
A TransferLink backed by a client-side RemoteSession.
The client always sends on stdin and receives on stdout, granting stdout credit as it consumes (flow control), regardless of transfer direction.
Constructors
- ClientTransferLink(RemoteSession _session)
-
Wraps
_session.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inbound
→ Stream<
Uint8List> -
Inbound bytes from the peer.
no setter
- queuedBytes → int
-
Bytes queued locally awaiting send credit (for backpressure).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
grantWindow(
int credit) → void -
Grants the peer
creditmore bytes of send window (flow control). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
List< int> bytes) → void -
Sends
bytesto the peer. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited