ExecResult class
The result of a one-shot ClientRuntime.execute.
Constructors
- ExecResult({required int exitCode, required Uint8List stdout, required Uint8List stderr})
- Creates an exec result.
Properties
- exitCode → int
-
The process exit code.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stderr → Uint8List
-
Captured standard error bytes.
final
- stderrText → String
-
Standard error decoded as UTF-8.
no setter
- stdout → Uint8List
-
Captured standard output bytes.
final
- stdoutText → String
-
Standard output decoded as UTF-8.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited