LocalCommand class abstract
A local OmnyShell command, invoked with a leading : and never forwarded to
the remote shell.
Constructors
Properties
-
aliases
→ List<
String> -
Aliases that also invoke this command.
no setter
- description → String
-
A one-line description shown by
:help.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The command name (without the leading
:).no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usage → String?
-
Optional multi-line usage/help text shown under the listing by
:help.no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
LocalCommandContext context, List< String> args) → Future<void> -
Runs the command with parsed
args. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited