LoginRequest class
A request to authenticate and persist a new login, built from the login form.
Constructors
- LoginRequest({required String hub, required String principal, required LoginMethod method, String secret = '', String? ca, bool insecure = false})
-
const
Properties
- ca → String?
-
Optional CA/cert PEM path to trust, remembered with the session.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hub → String
-
The Hub URL (
wss://host:port).final - insecure → bool
-
Whether to skip TLS certificate/hostname verification.
final
- method → LoginMethod
-
Whether secret is a token or a path to an Ed25519 seed file.
final
- principal → String
-
The principal (login name).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secret → String
-
The bearer token (token method) or seed-file path (publicKey method).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited