resumedInAltScreen property
bool
get
resumedInAltScreen
Whether this (resumed) session opened inside a full-screen program's alternate screen. When true, the host should attach in passthrough and not prime a prompt (the replayed output repaints the program; its already- queued completion marker restores the prompt when it exits).
Implementation
bool get resumedInAltScreen => _resumedInAltScreen;