remoteCompletionCommand function
Returns a POSIX sh command that prints completion candidates for word,
one per line. When isCommand is true the word is in command position.
Equivalent to const PosixShellDialect().completionCommand(...); for
non-POSIX nodes use the session's ShellDialect directly.
Implementation
String remoteCompletionCommand(String word, {required bool isCommand}) =>
const PosixShellDialect().completionCommand(word, isCommand: isCommand);