AiProvider class abstract
A chat provider that supports tool calling.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
chat(
{required List< AiMessage> messages, required List<AiToolSpec> tools, String? model}) → Future<AiResult> -
Sends the conversation
messages(the first may be a system message) and the availabletools, returning the model's next turn.modeloverrides the provider's configured default model for this call (used to switch between planner and executor models per phase);nulluses the default. -
close(
) → void - Releases any underlying resources (e.g. the HTTP client).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited