AiToolCall class
A single tool invocation requested by the model.
Constructors
Properties
-
arguments
→ Map<
String, Object?> -
The decoded JSON arguments object.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Provider-assigned call id, echoed back in the matching AiToolResult.
final
- name → String
-
The tool name (e.g.
run_command,present_plan).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited