The separator rule shown just before a plan — a distinct char and color from rule — that sets the plan apart from the preceding investigation.
@override String planRule(String text) => _sgr(35, text);