CommandRun class
The result of running a single command on the node.
Constructors
- CommandRun({required int exitCode, required String stdout, required String stderr})
-
const
Properties
- exitCode → int
-
The process exit code (0 = success).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ok → bool
-
Whether the command exited successfully.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stderr → String
-
Captured standard error (decoded text).
final
- stdout → String
-
Captured standard output (decoded text).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited