ShellPromptState class
The remote shell's prompt context, reported to the host when the shell returns to its (idle) prompt so the host can render a prompt line.
Constructors
- ShellPromptState({String? cwd, String? branch, String? gitStatus, String? privilege})
-
Creates a prompt state.
const
Properties
- branch → String?
-
The git branch of cwd, or
nulloutside a repo.final - cwd → String?
-
The remote working directory, or
nullif unknown.final - gitStatus → String?
-
Compact git status (
+staged ~modified ?untracked), ornullwhen clean.final - hashCode → int
-
The hash code for this object.
no setterinherited
- isRoot → bool
-
Whether the remote session is the superuser.
no setter
- privilege → String?
-
Privilege label (
rootfor the superuser), ornull.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited