AiProviderKind enum
The AI provider an AiConfig talks to.
xAI is intentionally omitted from v1; because its API is OpenAI-compatible it
can later be served by the OpenAI provider pointed at a different baseUrl.
Values
- anthropic → const AiProviderKind
- openai → const AiProviderKind
- gemini → const AiProviderKind
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wireName → String
-
The token used in
ai.yaml(its lowercase name).no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
tryParse(
String? value) → AiProviderKind? -
Decodes a provider token, returning
nullfor unknown values.
Constants
-
values
→ const List<
AiProviderKind> - A constant List of the values in this enum, in order of their declaration.