AuditRecord class

A single audit entry recording a security-relevant Hub event.

Constructors

AuditRecord({required DateTime at, required String action, String? principal, Map<String, dynamic> detail = const {}})
Creates an audit record.

Properties

action String
The action (e.g. auth.ok, auth.fail, session.open, session.rejected, session.close).
final
at DateTime
When the event occurred.
final
detail Map<String, dynamic>
Free-form structured detail.
final
hashCode int
The hash code for this object.
no setterinherited
principal String?
The acting principal id, if known.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited