PortRange class
An inclusive TCP port range [start, end].
Used to constrain dynamically allocated public ports so they stay within a range that a firewall is configured to allow.
Constructors
- PortRange(int start, int end)
-
const
- PortRange.parse(String spec)
-
Parses a
start-end(or singleport) string, e.g.20000-20100.factory
Properties
Methods
-
contains(
int port) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited