SessionRouter class
Holds the Hub's live session routes with O(1) lookup from either end and by session id.
Constructors
Properties
-
all
→ Iterable<
SessionRoute> -
All live routes.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
SessionRoute route) → void -
Registers a
route. -
byClient(
String connId, int channel) → SessionRoute? -
The route for a client-side
(connId, channel), ornull. -
byNode(
String connId, int channel) → SessionRoute? -
The route for a node-side
(connId, channel), ornull. -
bySession(
SessionId sessionId) → SessionRoute? -
The route with
sessionId, ornull. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
SessionId sessionId) → SessionRoute? -
Removes and returns the route with
sessionId, if present. -
removeForPeer(
String peerId) → List< SessionRoute> -
Removes and returns every route touching the peer connection
peerId(used when a client or node disconnects). -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited