PathDiff class
The difference between an old and new PATH, for the confirmation prompt.
Properties
-
added
→ List<
String> -
Entries present in the new PATH but not the old one (order preserved).
final
- changed → bool
-
Whether the new PATH differs from the old (a
nullold counts as changed).final - hashCode → int
-
The hash code for this object.
no setterinherited
-
removed
→ List<
String> -
Entries present in the old PATH but not the new one (order preserved).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited